@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import date
 from decimal import Decimal
 from typing import Optional, Tuple
 
@@ -19,12 +19,10 @@ class ChecksumGenerator(object):
             low = amount_as_cents - (tens_of_millons * 10**9)
         return high, low
 
-    def _fecha_to_bytearray(self, fecha_operacion: int) -> bytearray:
-        fecha_operacion_dt = datetime.strptime(str(fecha_operacion), '%Y%m%d')
-
-        day = int.to_bytes(int(fecha_operacion_dt.day), 1, 'big')
-        month = int.to_bytes(int(fecha_operacion_dt.month), 1, 'big')
-        year = int.to_bytes(int(fecha_operacion_dt.year), 2, 'big')
+    def _fecha_to_bytearray(self, fecha_operacion: date) -> bytearray:
+        day = int.to_bytes(int(fecha_operacion.day), 1, 'big')
+        month = int.to_bytes(int(fecha_operacion.month), 1, 'big')
+        year = int.to_bytes(int(fecha_operacion.year), 2, 'big')
 
         return bytearray(day + month + year)
 
