@@ -1,4 +1,5 @@
 import re
+from datetime import date, datetime
 from typing import Any, Dict, Optional
 
 from lxml import etree
@@ -7,6 +8,7 @@ from pydantic import BaseModel, ConfigDict, field_validator
 
 from spei import types
 from spei.resources.validators import normalize_invalid_chars
+from spei.types.common import InstitutionCode
 from spei.utils import to_camel_case, to_pascal_case, to_snake_case  # noqa: WPS347
 
 SOAP_NS = 'http://schemas.xmlsoap.org/soap/envelope/'
@@ -28,7 +30,7 @@ class Orden(BaseModel):
 
     id: int
     categoria: types.CategoriaOrdenPago
-    op_fecha_oper: DateInt
+    op_fecha_oper: date
     op_folio: int
     op_monto: str
     op_tp_clave: types.TipoPagoOrdenPago
@@ -85,7 +87,7 @@ class Orden(BaseModel):
     # original info
     op_folio_ori: Optional[int] = None
     paq_folio_ori: Optional[int] = None
-    op_fecha_oper_ori: Optional[DateInt] = None
+    op_fecha_oper_ori: Optional[date] = None
     op_rastreo_ori: Optional[str] = None
     op_monto_intereses: Optional[float] = None
     op_monto_ori: Optional[float] = None
@@ -105,7 +107,7 @@ class Orden(BaseModel):
     op_cert_comer_env: Optional[int] = None
     op_digito_ver_comer: Optional[int] = None
     # karpay system info
-    op_fecha_cap: Optional[DateInt] = None
+    op_fecha_cap: Optional[date] = None
     op_folio_servidor: Optional[int] = None
     op_usu_autoriza: Optional[str] = None
     op_err_clave: Optional[types.CodigoError] = None
@@ -149,52 +151,50 @@ class Orden(BaseModel):
             nsmap=None,
         )
 
-        elements = self.dict(
+        elements = self.model_dump(
             exclude_none=True,
             exclude={'id', 'categoria', 'op_ins_clave_ord'},
         )
 
         for element, value in elements.items():  # noqa: WPS110
-            if element in self.model_fields:
-                if element == 'op_ins_clave_ben':
-                    subelement = etree.SubElement(
-                        ordenpago,
-                        'OpInsClave',
-                        attrib={},
-                        nsmap=None,
-                    )
-                    subelement.text = str(value)
-                    continue
-
-                if element == 'op_firma_dig':  # Lower case o in op
-                    subelement = etree.SubElement(
-                        ordenpago,
-                        'opFirmaDig',
-                        attrib={},
-                        nsmap=None,
-                    )
-                    subelement.text = str(value)
-                    continue
-
-                text = normalize_invalid_chars(str(value))
-
-                if element in _CAMEL_CASE_FIELDS:
-                    subelement = etree.SubElement(
-                        ordenpago,
-                        to_camel_case(element),
-                        attrib={},
-                        nsmap=None,
-                    )
-                    subelement.text = text
-                    continue
+            if element not in self.model_fields:
+                continue
 
+            if element == 'op_ins_clave_ben':
                 subelement = etree.SubElement(
                     ordenpago,
-                    to_pascal_case(element),
+                    'OpInsClave',
                     attrib={},
                     nsmap=None,
                 )
-                subelement.text = text
+                subelement.text = str(value)
+                continue
+
+            if element == 'op_firma_dig':  # Lower case o in op
+                subelement = etree.SubElement(
+                    ordenpago,
+                    'opFirmaDig',
+                    attrib={},
+                    nsmap=None,
+                )
+                subelement.text = str(value)
+                continue
+
+            if 'op_fecha' in element:
+                value = value.strftime('%Y%m%d')
+
+            tag = (
+                to_camel_case(element)
+                if element in _CAMEL_CASE_FIELDS
+                else to_pascal_case(element)
+            )
+            subelement = etree.SubElement(
+                ordenpago,
+                tag,
+                attrib={},
+                nsmap=None,
+            )
+            subelement.text = normalize_invalid_chars(str(value))
 
         return ordenpago
 
@@ -232,5 +232,11 @@ class Orden(BaseModel):
             orden_data['op_firma_dig'] = stripped
             return
 
-        if tag in cls.__fields__:
-            orden_data[tag] = stripped
+        if tag not in cls.model_fields:
+            return
+
+        if 'op_fecha' in tag:
+            orden_data[tag] = datetime.strptime(stripped, '%Y%m%d').date()
+            return
+
+        orden_data[tag] = stripped
